package cn.iocoder.yudao.module.contract.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import cn.iocoder.yudao.module.contract.entity.InspectionContract;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * inspectionContractMapper接口
 *
 * @author ruoyi
 * @date 2023-08-31
 */
@Mapper
public interface InspectionContractMapper  extends BaseMapper<InspectionContract>
{
    /**
     * 查询inspectionContract
     *
     * @param id inspectionContract主键
     * @return inspectionContract
     */
    public InspectionContract selectInspectionContractById(Long id);

    /**
     * 查询inspectionContract列表
     *
     * @param inspectionContract inspectionContract
     * @return inspectionContract集合
     */
    public IPage<InspectionContract> selectInspectionContractList(Page<InspectionContract> page, InspectionContract inspectionContract);

    /**
     * 新增inspectionContract
     *
     * @param inspectionContract inspectionContract
     * @return 结果
     */
    public int insertInspectionContract(InspectionContract inspectionContract);

    /**
     * 修改inspectionContract
     *
     * @param inspectionContract inspectionContract
     * @return 结果
     */
    public int updateInspectionContract(InspectionContract inspectionContract);

    /**
     * 删除inspectionContract
     *
     * @param id inspectionContract主键
     * @return 结果
     */
    public int deleteInspectionContractById(Long id);

    /**
     * 批量删除inspectionContract
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectionContractByIds(Long[] ids);
}
